@@ -128,6 +128,10 @@ class Signer(object):
             return {'type': 'SigningBox', 'handle': self.box_handle}
         return {'type': 'None'}
 
+    @staticmethod
+    def none() -> 'Signer':
+        return Signer()
+
     @staticmethod
     def from_keypair(keypair: KeyPair) -> 'Signer':
         return Signer(keypair=keypair)
@@ -301,6 +305,10 @@ class AccountForExecutor(object):
             }
         return {'type': 'None'}
 
+    @staticmethod
+    def none() -> 'AccountForExecutor':
+        return AccountForExecutor()
+
     @staticmethod
     def uninit() -> 'AccountForExecutor':
         """
